@@ -12,7 +12,7 @@ use DBIx::Log4perl::Constants qw (:masks $LogMask);
 use DBIx::Log4perl::db;
 use DBIx::Log4perl::st;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 require Exporter;
 our @ISA = qw(Exporter DBI);		# look in DBI for anything we don't do
 
@@ -237,7 +237,7 @@ Log::Log4perl handle.
 
 =head1 DESCRIPTION
 
-B<NOTE: The names of DBIx::Log4perl attributes have changed in version
+B<NOTE: The names of DBIx::Log4perl L</ATTRIBUTES> have changed in version
 0.18. They are now all lowercased as per the DBI specification.>
 
 C<DBIx::Log4perl> is a wrapper over DBI which adds logging of your DBI
@@ -298,6 +298,12 @@ This variable controls the amount of logging logged to the
 Log::Log4perl handle. There are a number of constants defined which
 may be ORed together to obtain the logging level you require:
 
+=head1 CONSTANTS
+
+The following constants may be imported via the C<:masks> group
+
+  use DBIx::Log4perl qw(:masks);
+
 =over
 
 =item DBIX_L4P_LOG_DEFAULT
